# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Perl binding of Sendmail Milter protocol
Name:		perl-Sendmail-PMilter
Version:	1.27
Release:	1.%{__distinit}%{__distvers}
License:	BSD-3-Clause
URL:		https://metacpan.org/release/Sendmail-PMilter
Source0:	https://cpan.metacpan.org/authors/id/G/GW/GWHAYWOOD/Sendmail-PMilter-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(IO::Select)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(IO::Socket::IP)
BuildRequires:	perl(IO::Socket::UNIX)
BuildRequires:	perl(parent)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Socket6)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Thread::Semaphore)
BuildRequires:	perl(threads)
BuildRequires:	perl(threads::shared)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(UNIVERSAL)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(IO::Socket::INET)
Requires:	perl(IO::Socket::IP)
Requires:	perl(IO::Socket::UNIX)
Requires:	perl(Socket6)
Requires:	perl(Thread::Semaphore)
Requires:	perl(threads)
Requires:	perl(threads::shared)

%description
Sendmail::PMilter is a mail filtering API implementing the Sendmail milter
protocol in pure Perl. This allows Sendmail servers (and perhaps other MTAs
implementing milter) to filter and modify mail in transit during the SMTP
connection, all in Perl.

It should be noted that PMilter 0.90 and later is NOT compatible with
scripts written for PMilter 0.5 and earlier.  The API has been reworked
significantly, and the enhanced APIs and rule logic provided by PMilter
0.5 and earlier has been factored out for inclusion in a separate package
called Mail::Milter.

%prep
%setup -q -n Sendmail-PMilter-%{version}

# Fix interpreters in examples and turn off exec bits to avoid extra deps
sed -i -e 's@/usr/local/bin/perl@/usr/bin/perl@' examples/*.pl
chmod -c -x examples/*.pl

%build
# Using "echo" to bypass the interactive 'yes/no' question in Makefile.PL
echo yes | perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
# Note: COPYRIGHT file is identical to LICENSE file
%license LICENSE
%doc ABOUT ACKNOWLEDGEMENTS Changes CONTRIBUTING README README.%{version} TODO
%doc examples/
%{perl_vendorlib}/Sendmail/
%{_mandir}/man3/Sendmail::PMilter.3*
%{_mandir}/man3/Sendmail::PMilter::Context.3*

%changelog
* Mon Feb  5 2024 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Proper handling of die (CPAN RT#150737)
  - Fix child_exit and add milter_exit (CPAN RT#150611)
  - Setconn with unix socket permissions (CPAN RT#150270)

* Wed Jul 19 2023 Paul Howarth <paul@city-fan.org> - 1.24-2
- Drop MODULE_COMPAT dependency from Fedora 38 onwards

* Fri Dec 16 2022 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Make no reply to MTA from the abort callback: such replies seem to cause
    problems for Postfix (CPAN RT#145263)

* Mon Oct 31 2022 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Replace deprecated IO::Socket::INET6 with IO::Socket::IP (CPAN RT#144401)
  - Most callbacks were not recognized unless the appropriate flags were set
    during the negotiate callback (CPAN RT#144971, CPAN RT#144273)
  - Packaging improvements (CPAN RT#130084)
- Use SPDX-format license tag


* Tue Jul  5 2022 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - New maintainership (CPAN/GWHAYWOOD)
  - Test suite updates
  - Implement set multi-line reply function (CPAN RT#125090)
  - Documentation updates (CPAN RT#125040)
    - Fix POD errors
    - Add COPYRIGHT->LICENCE (file,link,=head1)
    - Remove obsolete doc/
  - SETSENDER->CHGFROM etc. (CPAN RT#115352)
  - ithread and postfork dispatcher fixes (CPAN RT#85833)
  - sig{CHLD}='DEFAULT'; (CPAN RT#85826)
  - Macro and headers fixes (CPAN RT#84941)
  - Define constant SMFIF_NONE (CPAN RT#78865)
  - Dummy functions setdbg() and settimeout() return 1 (CPAN RT#50144)
  - Fix memory leak in ithread dispatcher (CPAN RT#54794)
  - Removed requirement for Sendmail::Milter (CPAN RT#23921)
  - Full support for protocol negotiation, including support for setting milter
    data buffer sizes
  - Add get_sendmail_option() to read configuration file options
  - Propose to insist on Milter Protocol Version 6 in V1.21
  - Removed enable_chgfrom and some other some cruft
  - Partial support for negotiation
  - Comments invited via CPAN issues
  - Added file CONTRIBUTING
  - Added file COPYRIGHT
- New upstream maintainer GWHAYWOOD
- Switch upstream from search.cpan.org to metacpan.org
- Drop old obsolete of perl-Sendmail-Milter

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 1.00-21
- Add versioned provide for perl-Sendmail-Milter
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Aug  5 2016 Paul Howarth <paul@city-fan.org> - 1.00-17
- Classify buildreqs by usage
- Simplify find command using -delete

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 1.00-12
- Drop %%defattr, redundant since rpm 4.4

* Thu Jun 13 2013 Paul Howarth <paul@city-fan.org> - 1.00-6
- Reset SIGCHLD handler in milters (CPAN RT#85826, #970138)
- Block instead of erroring on max children (CPAN RT#85833, #970197)
- BR: perl(Thread::Semaphore) and perl(Time::HiRes)
- BR:/R: all optional modules for different socket/dispatcher styles

* Tue Apr 30 2013 Paul Howarth <paul@city-fan.org> - 1.00-5
- Fix addheader, getsymval bugs (CPAN RT#84941, #957886)

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.00-4
- BR: perl(base), perl(Carp), perl(constant), perl(IO::Select) and perl(Socket)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 1.00-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 18 2011 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - Avoid infinite loop: signal handler modifies errno
  - Added support for SMFIC_UNKNOWN
- Nobody else likes macros for commands

* Mon Feb  7 2011 Paul Howarth <paul@city-fan.org> - 0.99-1
- Update to 0.99
  - Handle IPv6 addresses in SMFIC_CONNECT in Sendmail::PMilter::Context
    (CPAN RT#65499)

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.98-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 0.98-2
- Fix dist tag to work with RHEL6 Beta

* Sat Mar 13 2010 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98 (fixes for CPAN RT#51713 and CPAN RT#51759)
- Drop upstreamed POD patch (CPAN RT#51713)

* Mon Feb  8 2010 Paul Howarth <paul@city-fan.org> - 0.97-3
- Cosmetic changes merged from Fedora package

* Mon Feb  8 2010 Paul Howarth <paul@city-fan.org> - 0.97-2
- Add patch to handle SMFIC_DATA (CPAN RT#51058)
- Add patch from Fedora to fix POD errors in Sendmail::PMilter::Context
- Add patch for more POD fixes (CPAN RT#51713)
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 0.97-1
- Update to 0.97 (compatible with sendmail 8.14 - CPAN RT#43327)
- Add patch to make the no-op functions Sendmail::Milter::{setdb,settimeout}
  return "success" values to avoid messages like "Failed to set timeout value!"

* Thu Sep 24 2009 Paul Howarth <paul@city-fan.org> - 0.96-2
- Don't provide perl-Sendmail-Milter; avoids self-obsoletion
- Define RPM macros in global context

* Wed Apr 30 2008 Paul Howarth <paul@city-fan.org> - 0.96-1
- First RPM build
